/**
 * Communication OSC avec PD
 * Comment envoyer à et recevoir des messages OSC depuis Pure Data.
 *
 * OSC communication between Processing and PD
 * how to send to and receive osc messages from Pure Data.
 * oscP5 website : http://www.sojamo.de/oscP5
 */

// Importer la librairie oscP5
// netP5 est indispensable aussi
import oscP5.*;
import netP5.*;

OscP5 oscP5;

// position de l'étoile
int xp;
int yp;

// rayon
float xr;
float yr;

// direction du vecteur et son angle
float xdir;
float ydir;
int angle;
float theta;

//intensité 
int lux;

void setup() {

  // Parametres graphiques
  size(500, 500);
  frameRate(20);
  background(0);
  colorMode(HSB, 100);
  strokeWeight(4);

  // Position centrale de l'étoile au demarrage
  xp=width/2;
  yp=height/2;
  angle=0;

  /* Demarrer oscP5
   * Un numero de port sert a recevoir des messages venant de l'exterieur.
   * The port number is to listen for incoming messages */
  oscP5 = new OscP5(this, 2200);
}


/* Reception de messages OSC envoyes par PD
/* Incoming OSC messages from PD. */
float volson, capteur, oscille;

void oscEvent(OscMessage message_PD) {
  /* Trie les messages arrivant en fonction de leur adresse
   * Check the address pattern of the received OscMessage */
  /* Attention aux types de variables envoyees depuis PD, int ou float.
  /* Beware the PD variable type, int or float 
   */

  // Volume sonore
  if (message_PD.checkAddrPattern("/sonore")==true) {
    volson = message_PD.get(0).floatValue();
    println(" Message /sonore : "+ volson);
    volson = map(volson, 35, 90, 0, 100);
  }

  // Valeurs du capteur
  if (message_PD.checkAddrPattern("/capt")==true) {
    /* Attribution de la valeur du message a une variable du meme type.
     * Assign the message value to a variable of the same datatype. */
    capteur = float(message_PD.get(0).intValue());
    println(" Message /capt : "+ capteur);
    capteur = map(capteur, 0, 127, 0, 100);
  }

  // Oscillation aléatoire
  if (message_PD.checkAddrPattern("/oscil")==true) {
    oscille = message_PD.get(0).floatValue();
    println(" Message /oscil : "+ oscille);
  }
}


void draw() {

  // vecteur tournant
  angle=angle+1;
  theta=(2*PI*angle)/360;
  xdir=cos(theta);
  ydir=sin(theta);
  lux=int(volson*2);
  tracer_rayon(xp, yp, xr, yr, xdir, ydir, lux);

  // Attenuation progressive
  fill(0, 0.8);
  noStroke();
  rect(0, 0, width, height);
}


// Fonction de dessin d'un rayon
void tracer_rayon(int xp, int yp, float xr, float yr, float xdir, float ydir, int lux) {
  xr=lux*xdir+xp;
  yr=lux*ydir+yp;
  stroke(volson, capteur, oscille);
  line(xp, yp, xr, yr);
}

